@@ -27,13 +27,15 @@ import (
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/operatorclient"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/ownerutil"
+	"github.com/operator-framework/operator-lifecycle-manager/test/e2e/ctx"
 )
 
 var _ = Describe("Catalog", func() {
+	AfterEach(func() {
+		TearDown(testNamespace)
+	})
+
 	It("loading between restarts", func() {
-
-		defer cleaner.NotifyTestComplete(true)
-
 		// create a simple catalogsource
 		packageName := genName("nginx")
 		stableChannel := "stable"
@@ -48,10 +50,8 @@ var _ = Describe("Catalog", func() {
 			},
 		}
 
-		crdPlural := genName("ins")
-		crd := newCRD(crdPlural)
-		namedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-		csv := newCSV(packageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
+		crd := newCRD(genName("ins"))
+		csv := newCSV(packageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, nil)
 
 		c := newKubeClient()
 		crc := newCRClient()
@@ -89,8 +89,6 @@ var _ = Describe("Catalog", func() {
 	})
 	It("global update triggers subscription sync", func() {
 
-		defer cleaner.NotifyTestComplete(true)
-
 		globalNS := operatorNamespace
 		c := newKubeClient()
 		crc := newCRClient()
@@ -111,13 +109,9 @@ var _ = Describe("Catalog", func() {
 
 		stableChannel := "stable"
 
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-
-		crdPlural := genName("ins-")
-
-		mainCRD := newCRD(crdPlural)
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, mainNamedStrategy)
-		replacementCSV := newCSV(mainPackageReplacement, testNamespace, mainPackageStable, semver.MustParse("0.2.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, mainNamedStrategy)
+		mainCRD := newCRD(genName("ins-"))
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, nil)
+		replacementCSV := newCSV(mainPackageReplacement, testNamespace, mainPackageStable, semver.MustParse("0.2.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, nil)
 
 		mainCatalogName := genName("mock-ocs-main-")
 
@@ -198,8 +192,6 @@ var _ = Describe("Catalog", func() {
 	})
 	It("config map update triggers registry pod rollout", func() {
 
-		defer cleaner.NotifyTestComplete(true)
-
 		mainPackageName := genName("nginx-")
 		dependentPackageName := genName("nginxdep-")
 
@@ -208,14 +200,9 @@ var _ = Describe("Catalog", func() {
 
 		stableChannel := "stable"
 
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-		dependentNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-
-		crdPlural := genName("ins-")
-
-		dependentCRD := newCRD(crdPlural)
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, mainNamedStrategy)
-		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, dependentNamedStrategy)
+		dependentCRD := newCRD(genName("ins-"))
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, nil)
+		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, nil)
 
 		c := newKubeClient()
 		crc := newCRClient()
@@ -303,7 +290,7 @@ var _ = Describe("Catalog", func() {
 		subscription, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionStateAtLatestChecker)
 		require.NoError(GinkgoT(), err)
 		require.NotNil(GinkgoT(), subscription)
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
+		_, err = fetchCSV(crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
 		require.NoError(GinkgoT(), err)
 
 		ipList, err := crc.OperatorsV1alpha1().InstallPlans(testNamespace).List(context.TODO(), metav1.ListOptions{})
@@ -317,8 +304,6 @@ var _ = Describe("Catalog", func() {
 	})
 	It("config map replace triggers registry pod rollout", func() {
 
-		defer cleaner.NotifyTestComplete(true)
-
 		mainPackageName := genName("nginx-")
 		dependentPackageName := genName("nginxdep-")
 
@@ -328,14 +313,9 @@ var _ = Describe("Catalog", func() {
 
 		stableChannel := "stable"
 
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-		dependentNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-
-		crdPlural := genName("ins-")
-
-		dependentCRD := newCRD(crdPlural)
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, mainNamedStrategy)
-		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, dependentNamedStrategy)
+		dependentCRD := newCRD(genName("ins-"))
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, nil)
+		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, nil)
 
 		c := newKubeClient()
 		crc := newCRClient()
@@ -391,7 +371,7 @@ var _ = Describe("Catalog", func() {
 		subscription, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionStateAtLatestChecker)
 		require.NoError(GinkgoT(), err)
 		require.NotNil(GinkgoT(), subscription)
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
+		_, err = fetchCSV(crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
 		require.NoError(GinkgoT(), err)
 	})
 	It("gRPC address catalog source", func() {
@@ -407,8 +387,6 @@ var _ = Describe("Catalog", func() {
 		// Update the "address" CatalogSources's Spec.Address field with the PodIP of the replacement copied pod's PodIP
 		// Wait for the replacement CSV to be Successful
 
-		defer cleaner.NotifyTestComplete(true)
-
 		mainPackageName := genName("nginx-")
 		dependentPackageName := genName("nginxdep-")
 
@@ -418,15 +396,10 @@ var _ = Describe("Catalog", func() {
 
 		stableChannel := "stable"
 
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-		dependentNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-
-		crdPlural := genName("ins-")
-
-		dependentCRD := newCRD(crdPlural)
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, mainNamedStrategy)
-		replacementCSV := newCSV(mainPackageReplacement, testNamespace, mainPackageStable, semver.MustParse("0.2.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, mainNamedStrategy)
-		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, dependentNamedStrategy)
+		dependentCRD := newCRD(genName("ins-"))
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, nil)
+		replacementCSV := newCSV(mainPackageReplacement, testNamespace, mainPackageStable, semver.MustParse("0.2.0"), nil, []apiextensions.CustomResourceDefinition{dependentCRD}, nil)
+		dependentCSV := newCSV(dependentPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{dependentCRD}, nil, nil)
 
 		c := newKubeClient()
 		crc := newCRClient()
@@ -520,7 +493,7 @@ var _ = Describe("Catalog", func() {
 		subscription, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionStateAtLatestChecker)
 		require.NoError(GinkgoT(), err)
 		require.NotNil(GinkgoT(), subscription)
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, testNamespace, csvSucceededChecker)
+		_, err = fetchCSV(crc, subscription.Status.CurrentCSV, testNamespace, csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 
 		// Update the catalog's address to point at the other registry pod's cluster ip
@@ -534,26 +507,21 @@ var _ = Describe("Catalog", func() {
 		_, err = awaitCSV(GinkgoT(), crc, testNamespace, replacementCSV.GetName(), csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 	})
+
 	It("delete internal registry pod triggers recreation", func() {
 
 		// Create internal CatalogSource containing csv in package
 		// Wait for a registry pod to be created
-		// Create a Subscription for package
-		// Wait for the Subscription to succeed
-		// Wait for csv to succeed
 		// Delete the registry pod
 		// Wait for a new registry pod to be created
 
-		defer cleaner.NotifyTestComplete(true)
-
 		// Create internal CatalogSource containing csv in package
 		packageName := genName("nginx-")
 		packageStable := fmt.Sprintf("%s-stable", packageName)
 		stableChannel := "stable"
-		namedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
 		sourceName := genName("catalog-")
 		crd := newCRD(genName("ins-"))
-		csv := newCSV(packageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
+		csv := newCSV(packageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, nil)
 		manifests := []registry.PackageManifest{
 			{
 				PackageName: packageName,
@@ -579,57 +547,39 @@ var _ = Describe("Catalog", func() {
 
 		// Store the UID for later comparison
 		uid := registryPods.Items[0].GetUID()
-		name := registryPods.Items[0].GetName()
-
-		// Create a Subscription for package
-		subscriptionName := genName("sub-")
-		cleanupSubscription := createSubscriptionForCatalog(crc, testNamespace, subscriptionName, sourceName, packageName, stableChannel, "", v1alpha1.ApprovalAutomatic)
-		defer cleanupSubscription()
-
-		// Wait for the Subscription to succeed
-		subscription, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionStateAtLatestChecker)
-		require.NoError(GinkgoT(), err)
-		require.NotNil(GinkgoT(), subscription)
-
-		// Wait for csv to succeed
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, testNamespace, csvSucceededChecker)
-		require.NoError(GinkgoT(), err)
 
 		// Delete the registry pod
-		err = c.KubernetesInterface().CoreV1().Pods(testNamespace).Delete(context.TODO(), name, metav1.DeleteOptions{})
-		require.NoError(GinkgoT(), err)
+		Eventually(func() error {
+			backgroundDeletion := metav1.DeletePropagationBackground
+			return c.KubernetesInterface().CoreV1().Pods(testNamespace).DeleteCollection(context.TODO(), metav1.DeleteOptions{PropagationPolicy: &backgroundDeletion}, metav1.ListOptions{LabelSelector: selector.String()})
+		}).Should(Succeed())
 
 		// Wait for a new registry pod to be created
 		notUID := func(pods *corev1.PodList) bool {
+			uids := make([]string, 0)
 			for _, pod := range pods.Items {
+				uids = append(uids, string(pod.GetUID()))
 				if pod.GetUID() == uid {
+					ctx.Ctx().Logf("waiting for %v not to contain %s", uids, uid)
 					return false
 				}
 			}
-
-			return true
+			ctx.Ctx().Logf("waiting for %v to not be empty and not contain %s", uids, uid)
+			return len(pods.Items) > 0
 		}
 		registryPods, err = awaitPods(GinkgoT(), c, testNamespace, selector.String(), unionPodsCheck(singlePod, notUID))
 		require.NoError(GinkgoT(), err, "error waiting for replacement registry pod")
 		require.NotNil(GinkgoT(), registryPods, "nil replacement registry pods")
 		require.Equal(GinkgoT(), 1, len(registryPods.Items), "unexpected number of replacement registry pods found")
 	})
+
 	It("delete gRPC registry pod triggers recreation", func() {
 
 		// Create gRPC CatalogSource using an external registry image (community-operators)
 		// Wait for a registry pod to be created
-		// Create a Subscription for package
-		// Wait for the Subscription to succeed
-		// Wait for csv to succeed
 		// Delete the registry pod
 		// Wait for a new registry pod to be created
 
-		defer cleaner.NotifyTestComplete(true)
-
-		sourceName := genName("catalog-")
-		packageName := "etcd"
-		channelName := "clusterwide-alpha"
-
 		// Create gRPC CatalogSource using an external registry image (community-operators)
 		source := &v1alpha1.CatalogSource{
 			TypeMeta: metav1.TypeMeta{
@@ -637,7 +587,7 @@ var _ = Describe("Catalog", func() {
 				APIVersion: v1alpha1.CatalogSourceCRDAPIVersion,
 			},
 			ObjectMeta: metav1.ObjectMeta{
-				Name:      sourceName,
+				Name:      genName("catalog-"),
 				Namespace: testNamespace,
 			},
 			Spec: v1alpha1.CatalogSourceSpec{
@@ -649,9 +599,6 @@ var _ = Describe("Catalog", func() {
 		crc := newCRClient()
 		source, err := crc.OperatorsV1alpha1().CatalogSources(source.GetNamespace()).Create(context.TODO(), source, metav1.CreateOptions{})
 		require.NoError(GinkgoT(), err)
-		defer func() {
-			require.NoError(GinkgoT(), crc.OperatorsV1alpha1().CatalogSources(source.GetNamespace()).Delete(context.TODO(), source.GetName(), metav1.DeleteOptions{}))
-		}()
 
 		// Wait for a new registry pod to be created
 		c := newKubeClient()
@@ -664,40 +611,32 @@ var _ = Describe("Catalog", func() {
 
 		// Store the UID for later comparison
 		uid := registryPods.Items[0].GetUID()
-		name := registryPods.Items[0].GetName()
-
-		// Create a Subscription for package
-		subscriptionName := genName("sub-")
-		cleanupSubscription := createSubscriptionForCatalog(crc, source.GetNamespace(), subscriptionName, source.GetName(), packageName, channelName, "", v1alpha1.ApprovalAutomatic)
-		defer cleanupSubscription()
-
-		// Wait for the Subscription to succeed
-		subscription, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionStateAtLatestChecker)
-		require.NoError(GinkgoT(), err)
-		require.NotNil(GinkgoT(), subscription)
-
-		// Wait for csv to succeed
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
-		require.NoError(GinkgoT(), err)
 
 		// Delete the registry pod
-		require.NoError(GinkgoT(), c.KubernetesInterface().CoreV1().Pods(testNamespace).Delete(context.TODO(), name, metav1.DeleteOptions{}))
+		Eventually(func() error {
+			backgroundDeletion := metav1.DeletePropagationBackground
+			return c.KubernetesInterface().CoreV1().Pods(testNamespace).DeleteCollection(context.TODO(), metav1.DeleteOptions{PropagationPolicy: &backgroundDeletion}, metav1.ListOptions{LabelSelector: selector.String()})
+		}).Should(Succeed())
 
 		// Wait for a new registry pod to be created
 		notUID := func(pods *corev1.PodList) bool {
+			uids := make([]string, 0)
 			for _, pod := range pods.Items {
+				uids = append(uids, string(pod.GetUID()))
 				if pod.GetUID() == uid {
+					ctx.Ctx().Logf("waiting for %v not to contain %s", uids, uid)
 					return false
 				}
 			}
-
-			return true
+			ctx.Ctx().Logf("waiting for %v to not be empty and not contain %s", uids, uid)
+			return len(pods.Items) > 0
 		}
 		registryPods, err = awaitPods(GinkgoT(), c, testNamespace, selector.String(), unionPodsCheck(singlePod, notUID))
 		require.NoError(GinkgoT(), err, "error waiting for replacement registry pod")
 		require.NotNil(GinkgoT(), registryPods, "nil replacement registry pods")
 		require.Equal(GinkgoT(), 1, len(registryPods.Items), "unexpected number of replacement registry pods found")
 	})
+
 	It("image update", func() {
 		if os.Getenv("GITHUB_ACTIONS") == "true" {
 			Skip("This spec fails when run using KIND cluster. See https://github.com/operator-framework/operator-lifecycle-manager/issues/1380 for more details")
@@ -775,7 +714,6 @@ var _ = Describe("Catalog", func() {
 		}
 
 		// 2. setup catalog source
-		defer cleaner.NotifyTestComplete(true)
 
 		sourceName := genName("catalog-")
 		packageName := "busybox"
@@ -833,7 +771,7 @@ var _ = Describe("Catalog", func() {
 		require.NotNil(GinkgoT(), subscription)
 
 		// Wait for csv to succeed
-		_, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
+		_, err = fetchCSV(crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 
 		registryCheckFunc := func(podList *corev1.PodList) bool {
@@ -924,7 +862,7 @@ var _ = Describe("Catalog", func() {
 		require.NotNil(GinkgoT(), subscription)
 
 		// Wait for csv to succeed
-		csv, err := fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
+		csv, err := fetchCSV(crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 
 		// check version of running csv to ensure the latest version (0.9.2) was installed onto the cluster
@@ -946,7 +884,6 @@ var _ = Describe("Catalog", func() {
 		// Update the catalog to point to an image that contains the busybox v2 and busybox-dependency v2 images.
 		// Wait for the new Subscriptions to succeed and check if they include the new CSVs
 		// Wait for the CSVs to succeed and confirm that the have the correct Spec.Replaces fields.
-		defer cleaner.NotifyTestComplete(true)
 
 		sourceName := genName("catalog-")
 		packageName := "busybox"
@@ -966,7 +903,7 @@ var _ = Describe("Catalog", func() {
 			},
 			Spec: v1alpha1.CatalogSourceSpec{
 				SourceType: v1alpha1.SourceTypeGrpc,
-				Image:      catSrcImage + ":1.0.0",
+				Image:      catSrcImage + ":1.0.0-with-ListBundles-method",
 			},
 		}
 
@@ -1011,7 +948,7 @@ var _ = Describe("Catalog", func() {
 			if err != nil {
 				return false, err
 			}
-			existingSource.Spec.Image = catSrcImage + ":2.0.0"
+			existingSource.Spec.Image = catSrcImage + ":2.0.0-with-ListBundles-method"
 
 			source, err = crc.OperatorsV1alpha1().CatalogSources(source.GetNamespace()).Update(context.TODO(), existingSource, metav1.UpdateOptions{})
 			if err == nil {
@@ -1030,7 +967,7 @@ var _ = Describe("Catalog", func() {
 		require.NotNil(GinkgoT(), subscription)
 
 		// Wait for busybox v2 csv to succeed and check the replaces field
-		csv, err := fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
+		csv, err := fetchCSV(crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 		require.Equal(GinkgoT(), "busybox.v1.0.0", csv.Spec.Replaces)
 
@@ -1043,7 +980,7 @@ var _ = Describe("Catalog", func() {
 		require.NotNil(GinkgoT(), subscription)
 
 		// Wait for busybox-dependency v2 csv to succeed and check the replaces field
-		csv, err = fetchCSV(GinkgoT(), crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
+		csv, err = fetchCSV(crc, subscription.Status.CurrentCSV, subscription.GetNamespace(), csvSucceededChecker)
 		require.NoError(GinkgoT(), err)
 		require.Equal(GinkgoT(), "busybox-dependency.v1.0.0", csv.Spec.Replaces)
 	})
